@@ -175,6 +175,8 @@ def plot_pulls(**kwargs):
               help='If given, use custom background asimov dataset instead of generating on the fly.')
 @click.option('-o', '--outname', default='limits.json', show_default=True,
               help='Name of output')
+@click.option('--mu_exp', type=float, default=0, show_default=True,
+              help='Expected signal strengh value to be used for Asimov generation')
 @click.option('--blind/--unblind', 'do_blind', default=True, show_default=True,
               help='Blind/unblind analysis')
 @click.option('--CL', 'CL', type=float, default=0.95, show_default=True,
@@ -288,9 +290,9 @@ def harmonize_np(ws_files, reference, input_config_path, base_path, outfile):
         
         
 @click.command(name='generate_asimov')
-@click.option('-i', '--input_file', required=True, 
+@click.option('-i', '--input_file', 'filename', required=True, 
               help='Path to the input workspace file.')
-@click.option('-o', '--output_file', required=True, 
+@click.option('-o', '--output_file', 'outname', required=True, 
               help='Name of the output workspace containing the '
                    'generated asimov dataset.')
 @click.option('-p', '--poi', required=True, 
@@ -303,6 +305,12 @@ def harmonize_np(ws_files, reference, input_config_path, base_path, outfile):
               help='Perform nuisance parameter profiling with POI set at the specified value. '
                    'This option is only effective if do_fit is set to True. If None, POI is '
                    'set floating (i.e. unconditional maximum likelihood estimate).')
+@click.option('-f', '--fix', 'fix_param', default="", show_default=True,
+              help='Parameters to fix')
+@click.option('-r', '--profile', 'profile_param', default="", show_default=True,
+              help='Parameters to profile')
+@click.option('-s', '--snapshot', 'snapshot_name', default=None, show_default=True,
+              help='Name of initial snapshot')
 @click.option('--modify-globs/--keep-globs', default=True, show_default=True,
               help='Match the values of nuisance parameters and the corresponding global '
                    'observables when generating the asimov data. This is important for making '
@@ -311,6 +319,8 @@ def harmonize_np(ws_files, reference, input_config_path, base_path, outfile):
               help='Perform nuisance parameter profiling with a fit to the given dataset.')
 @click.option('--asimov_name', default="asimovData_{mu}", show_default=True,
               help='Name of the generated asimov dataset.')
+@click.option('--asimov_snapshot', default="asimovData_{mu}", show_default=True,
+              help='Name of the snapshot that generates the asimov dataset.')
 @click.option('-d', '--data', default='combData', show_default=True,
               help='Name of the dataset used in NP profiling.')
 @click.option('--constraint_option', default=0, show_default=True,
@@ -321,26 +331,45 @@ def harmonize_np(ws_files, reference, input_config_path, base_path, outfile):
 @click.option('-c', '--configuration', default=None,
               help='Path to the json configuration file containing'
                    ' the minimizer options for NP profiling.')
+@click.option('-v', '--verbosity', default='INFO', show_default=True,
+              type=click.Choice(["DEBUG", "INFO", "WARNING", "ERROR"], case_sensitive=False),
+              help='Verbosity level.')
 def generate_asimov(**kwargs):
     """
     Generate Asimov dataset
     """
-    input_filename = kwargs.pop("input_file")
-    output_filename = kwargs.pop("output_file")
-    if os.path.abspath(input_filename) == os.path.abspath(output_filename):
-        raise ValueError("output workspace file name cannnot be the same as the input workspace file name")
-    from quickstats.components import AnalysisObject
-    config_file = kwargs.pop("configuration")
+    from quickstats.components import AnalysisBase
+    filename      = kwargs.pop('filename')
+    data_name     = kwargs.pop('data')
+    poi_name      = kwargs.pop('poi')
+    outname       = kwargs.pop('outname')
+    verbosity     = kwargs.pop('verbosity')
+    fix_param     = kwargs.pop('fix_param')
+    profile_param = kwargs.pop('profile_param')
+    snapshot_name = kwargs.pop('snapshot_name')
+    config_file   = kwargs.pop('configuration')
     if config_file is not None:
         config = json.load(open(config_file, 'r'))
     else:
         config = {}
-    data_name = kwargs.pop("data")
-    kwargs['poi_name'] = kwargs.pop("poi")
-    task = AnalysisObject(filename=input_filename, data_name=data_name, **config)
-    task.model.generate_asimov(**kwargs)
-    task.model.save(output_filename)
-
+    config['fix_param'] = fix_param
+    config['profile_param'] = profile_param
+    config['snapshot_name'] = snapshot_name
+    asimov_config = {
+        "poi_val"         : kwargs.pop("poi_val"),
+        "poi_profile"     : kwargs.pop("poi_profile"),
+        "do_fit"          : kwargs.pop("do_fit"),
+        "modify_globs"    : kwargs.pop("modify_globs"),
+        "do_import"       : True,
+        "asimov_name"     : kwargs.pop("asimov_name"),
+        "asimov_snapshot" : kwargs.pop("asimov_snapshot"),
+        "constraint_option" : kwargs.pop("constraint_option"),
+        "restore_states"  : 0
+    }
+    analysis = AnalysisBase(filename, poi_name=poi_name, data_name=data_name,
+                            config=config, verbosity=verbosity)
+    analysis.generate_asimov(**asimov_config)
+    analysis.save(outname)
 
 @click.command(name='generate_standard_asimov')
 @click.option('-i', '--input_file', 'filename', required=True, 
@@ -376,6 +405,9 @@ def generate_asimov(**kwargs):
                    '\b\n 5: fit with POI free and constrained NP fixed to 0 and set POI to 1 after fit'
                    '\b\n -1: nominal NP with POI set to 0'
                    '\b\n -2: nominal NP with POI set to 1')
+@click.option('-v', '--verbosity', default='INFO', show_default=True,
+              type=click.Choice(["DEBUG", "INFO", "WARNING", "ERROR"], case_sensitive=False),
+              help='Verbosity level.')
 def generate_standard_asimov(**kwargs):
     """
     Generate standard Asimov dataset
@@ -390,6 +422,7 @@ def generate_standard_asimov(**kwargs):
     poi_scale = kwargs.pop("poi_scale")
     asimov_names = kwargs.pop("asimov_names")
     asimov_snapshots = kwargs.pop("asimov_snapshots")
+    verbosity = kwargs.pop("verbosity")
     config = {
         'fix_param': fix_param,
         'profile_param': profile_param,
@@ -399,12 +432,11 @@ def generate_standard_asimov(**kwargs):
         asimov_names = asimov_names.split(",")
     if asimov_snapshots is not None:
         asimov_snapshots = asimov_snapshots.split(",")        
-    generator = AsimovGenerator(**kwargs, config=config)
+    generator = AsimovGenerator(**kwargs, config=config, verbosity=verbosity)
     generator.generate_standard_asimov(asimov_types, poi_scale=poi_scale,
                                        asimov_names=asimov_names,
                                        asimov_snapshots=asimov_snapshots)
     generator.save(outname)
-    
 
 @click.command(name='toy_significance')
 @click.option('-i', '--input_file', 'filename', required=True, 
