@@ -10,18 +10,18 @@ import click
 @click.option('--display/--no-display', default=True, show_default=True,
               help='Display fit result.')
 @click.option('--save/--no-save', "save_result", default=False, show_default=True,
-              help='Save fit result')
+              help='Save fit result.')
 @click.option('--save_log/--skip_log', default=False, show_default=True,
-              help='Save log file')
+              help='Save log file.')
 @click.option('--save_ws', default=None, show_default=True,
               help='Save fitted workspace to a given path.')
 @click.option('--save_snapshot', default=None, show_default=True,
               help='Save fitted values of all variables as a snapshot and restore all variables to '
               'their initial values. Should be used together with --save_ws.')
 @click.option('--outdir', default="pulls", show_default=True,
-              help='Output directory for pulls output')
+              help='Output directory for pulls output.')
 @click.option('--export_as_np_pulls/--skip_export_as_np_pulls', default=False, show_default=True,
-              help='Export (constrained) NP results for pulls plot')
+              help='Export (constrained) NP results for pulls plot.')
 @click.option('-w', '--workspace', 'ws_name', default=None, show_default=True,
               help='Name of workspace. Auto-detect by default.')
 @click.option('-m', '--model_config', 'mc_name', default=None, show_default=True,
@@ -34,6 +34,8 @@ import click
               help='Parameters to profile')
 @click.option('-f', '--fix', 'fix_param', default="", show_default=True,
               help='Parameters to fix')
+@click.option('--pois', default="", show_default=True,
+              help='Define the set of POIs (separated by commas) sed for calculating Minos errors.')
 @click.option('--constrain/--no-constrain', 'constrain_nuis', default=True, show_default=True,
               help='Use constrained NLL (i.e. include systematics)')
 @click.option('-t', '--minimizer_type', default="Minuit2", show_default=True,
@@ -50,6 +52,8 @@ import click
               help='Default minimization strategy')
 @click.option('--hesse/--no-hesse', default=False, show_default=True,
               help='Evaluate errors using Hesse.')
+@click.option('--minos/--no-minos', default=False, show_default=True,
+              help='Evaluate errors using Minos.')
 @click.option('--print_level', type=int, default=-1, show_default=True,
               help='Minimizer print level')
 @click.option('--fix-cache/--no-fix-cache', default=True, show_default=True,
@@ -76,6 +80,8 @@ def likelihood_fit(**kwargs):
     """
     Perform likelihood fit on a workspace
     """
+    do_minos = kwargs.pop("minos")
+    pois = [poi for poi in kwargs.pop("pois").split(",") if poi]
     _kwargs = {}
     for arg_name in ["outname", "save_log", "display", "save_result",
                      "export_as_np_pulls", "outdir", "save_ws", "save_snapshot"]:
@@ -84,7 +90,7 @@ def likelihood_fit(**kwargs):
     for arg_name in ["filename", "data_name", "verbosity"]:
         _init_kwargs[arg_name] = kwargs.pop(arg_name)
     _init_kwargs['config'] = kwargs
-    _init_kwargs['poi_name'] = []
+    _init_kwargs['poi_name'] = pois
     from quickstats.components import AnalysisBase   
     if _kwargs['save_log']:
         from quickstats.concurrent.logging import standard_log
@@ -93,11 +99,11 @@ def likelihood_fit(**kwargs):
             analysis = AnalysisBase(**_init_kwargs)
             if _kwargs['export_as_np_pulls']:
                 analysis.minimizer.configure(hesse=True)
-            fit_result = analysis.nll_fit(mode=3)
+            fit_result = analysis.nll_fit(mode=3, do_minos=do_minos)
         print(f"INFO: Saved fit log to `{log_path}`")
     else:
         analysis = AnalysisBase(**_init_kwargs)
-        fit_result = analysis.nll_fit(mode=3)
+        fit_result = analysis.nll_fit(mode=3, do_minos=do_minos)
     output = {}
     output['fit_result'] = fit_result
     df = {'pois':{}, 'nuisance_parameters':{}}
