@@ -103,7 +103,37 @@ class AsimovGenerator(AnalysisObject):
         config['verbosity'] = verbosity
         self._inherit_init(super(AsimovGenerator, self).__init__, **config)
         
-    
+    def generate_asimov(self, poi_val:Optional[float]=None, 
+                        poi_profile:Optional[float]=None,
+                        do_fit:bool=True,
+                        modify_globs:bool=True,
+                        do_import:bool=True,
+                        asimov_name:Optional[str]=None,
+                        asimov_snapshot:Optional[str]=None,
+                        channel_asimov_name:Optional[str]=None,
+                        dataset:Optional["ROOT.RooDataSet"]=None,
+                        constraint_option:int=0,
+                        restore_states:int=0,
+                        snapshot_names:Optional[Dict]=None):
+        kwargs = {
+            "poi_name"            : self.poi.GetName(),
+            "poi_val"             : poi_val,
+            "poi_profile"         : poi_profile,
+            "do_fit"              : do_fit,
+            "modify_globs"        : modify_globs,
+            "do_import"           : do_import,
+            "asimov_name"         : asimov_name,
+            "asimov_snapshot"     : asimov_snapshot,
+            "channel_asimov_name" : channel_asimov_name,
+            "dataset"             : dataset,
+            "constraint_option"   : constraint_option,
+            "restore_states"      : restore_states,
+            "minimizer_options"   : self.minimizer_options,
+            "nll_options"         : self.nll_commands,
+            "snapshot_names"      : snapshot_names
+        }
+        self.model.generate_asimov(**kwargs)
+        
     def generate_standard_asimov(self, asimov_types:Optional[Union[List[AsimovType], List[int]]]=None,
                                  asimov_names:Optional[Union[List[str], str]]=None,
                                  asimov_snapshots:Optional[Union[List[str], str]]=None,
