@@ -28,7 +28,7 @@ class AsymptoticCLs(AnalysisObject):
     }
     
     def __init__(self, filename:str, poi_name:str=None, data_name:str='combData',
-                 asimov_data_name:Optional[str]=None,
+                 asimov_data_name:Optional[str]=None, mu_exp:float=0, mu_guess:float=1,
                  CL:float=0.95, precision:float=0.005, adjust_fit_range:bool=True,
                  do_tilde:bool=True, do_better_bands:bool=True, predictive_fit:bool=False,
                  better_negative_bands:bool=False, do_blind:bool=True,
@@ -90,6 +90,11 @@ class AsymptoticCLs(AnalysisObject):
         self.adjust_fit_range = adjust_fit_range
         self.direction = 1
         self.global_status = 0
+        self.mu_exp = mu_exp
+        if mu_guess == mu_exp:            
+            mu_guess = mu_guess + 0.1
+            self.stdout.info(f"INFO: Changed mu_guess to {mu_guess} so that it is different from mu_exp")
+        self.mu_guess = mu_guess
         
         # define asimov data
         if asimov_data_name is not None:
@@ -236,7 +241,7 @@ class AsymptoticCLs(AnalysisObject):
         self.poi.setConstant(0)
         asimov_0_nll = self.summary[0]['nll']
         if nll == asimov_0_nll:
-            self.set_poi_value(0)
+            self.set_poi_value(self.mu_exp)
             self.poi.setConstant(1)
         # case for observed limit
         if (nll not in self.nll_maps) or ('nll_mu_hat' not in self.nll_maps[nll]):
@@ -254,10 +259,13 @@ class AsymptoticCLs(AnalysisObject):
         
         if (mu_hat < 0.1) or (initial_guess != 0):
             self.set_poi_value(initial_guess)
-        
+
         mu = self.poi.getVal()
+        from pdb import set_trace
+        
         qmu = self.get_qmu(asimov_0_nll, mu)
-        sigma_guess = self.LimitTool.getSigma(mu, 0, qmu)
+        #set_trace()
+        sigma_guess = self.LimitTool.getSigma(mu, self.mu_exp, qmu)
         sigma_b = sigma_guess
         mu_guess = self.LimitTool.findCrossing(sigma_guess, sigma_b, mu_hat)
         pmu = self.LimitTool.calcPmu(qmu, sigma_b, mu_guess)
@@ -309,7 +317,7 @@ class AsymptoticCLs(AnalysisObject):
                     self.load_nll_snapshot(asimov_0_nll, mu_pre)
 
                 qmuA = self.get_qmu(asimov_0_nll, mu_guess)
-                sigma_b = self.LimitTool.getSigma(mu_guess, 0, qmuA)
+                sigma_b = self.LimitTool.getSigma(mu_guess, self.mu_exp, qmuA)
                 self.save_nll_snapshot(asimov_0_nll, mu_guess)
             else:
                 sigma_b = sigma_guess
@@ -508,8 +516,11 @@ class AsymptoticCLs(AnalysisObject):
         
         if self.asimov_data_0 is None:
             # generate asimov dataset on the fly
-            asimov_data_0 = self.model.generate_asimov(self.poi.GetName(), poi_val=0,
-                                                       poi_profile=0, 
+            fit_text = "postfit" if not self.do_blind else "nominal"
+            self.stdout.info(f"INFO: Generating asimov dataset with mu = {pretty_value(self.mu_exp)} using {fit_text} NP values")
+            asimov_data_0 = self.model.generate_asimov(self.poi.GetName(),
+                                                       poi_val=self.mu_exp,
+                                                       poi_profile=self.mu_exp, 
                                                        do_fit=not self.do_blind,
                                                        modify_globs=not self.do_blind,
                                                        dataset=self.data,
@@ -522,16 +533,16 @@ class AsymptoticCLs(AnalysisObject):
             
         asimov_0_nll = self.create_nll(asimov_data_0)
         self.summary[0] = {'dataset': asimov_data_0, 'nll': asimov_0_nll}
-        self.set_poi_value(0)
-        self.save_nll_snapshot(asimov_0_nll, 0)
-        self.load_conditional_snapshot(0, target=WSArgument.GLOBAL_OBSERVABLE)
-        self.load_conditional_snapshot(0, target=WSArgument.NUISANCE_PARAMETER)
+        self.set_poi_value(self.mu_exp)
+        self.save_nll_snapshot(asimov_0_nll, self.mu_exp)
+        self.load_conditional_snapshot(self.mu_exp, target=WSArgument.GLOBAL_OBSERVABLE)
+        self.load_conditional_snapshot(self.mu_exp, target=WSArgument.NUISANCE_PARAMETER)
         nll_value = asimov_0_nll.getVal()
-        self.fill_mappings(asimov_0_nll, asimov_data_0, 0, nll_value)
+        self.fill_mappings(asimov_0_nll, asimov_data_0, self.mu_exp, nll_value)
         
         self.LimitTool.setTargetCLs(1 - self.CL)
         
-        med_limit = self.get_limit(asimov_0_nll, 1.0, 0)
+        med_limit = self.get_limit(asimov_0_nll, self.mu_guess, 0)
         approx_limits = self.get_approx_limits(med_limit, self.LimitTool.getTargetCLs())
         limits = approx_limits.copy()
         
@@ -553,7 +564,7 @@ class AsymptoticCLs(AnalysisObject):
             limits[n] = self.evaluate_limit_band(n, med_limit)
         
         # compute observed limit
-        self.load_conditional_snapshot(0, target=WSArgument.NUISANCE_PARAMETER)
+        self.load_conditional_snapshot(self.mu_exp, target=WSArgument.NUISANCE_PARAMETER)
         # relax the range for observed limit
         if not self.adjust_fit_range:
             self.poi.setRange(poi_range_tmp[0], poi_range_tmp[1])
