@@ -29,7 +29,9 @@ class WSArgument(DescriptiveEnum):
     CONSTRAINT                        = (12, "Tuple of constraint pdf and the associated nuisance parameter and global observable", False)
     AUXILIARY                         = (13, "Auxiliary variables (All variables except POIs, observables, global observables and "
                                              "nuisance parameters)", True)
-    CORE                              = (14, "Nuisance parameters, global observables and POIs", True)    
+    CORE                              = (14, "Nuisance parameters, global observables and POIs", True)
+    MUTABLE                           = (15, "Mutable parameters (Nuisance parameters, global observables, POIs and floating auxiliary"
+                                             " parameters)", True)
     
     def __init__(self, enum_id:int, description:str="", is_variable:bool=False):
         super().__init__(enum_id=enum_id, description=description)
