@@ -1064,8 +1064,10 @@ class ExtendedModel(AbstractObject):
             self.stdout.info(f'INFO: Generated Asimov Dataset \"{asimov_data_name}\"')
             
         if asimov_snapshot is not None:
-            self.stdout.info('INFO: Saving snapshot "{}"'.format(asimov_snapshot))
-            ws.saveSnapshot(asimov_snapshot, mutable_vars)
+            snapshot_name = asimov_snapshot.format(mu=pretty_value(poi_val),
+                                                   mu_cond=pretty_value(poi_profile))
+            self.stdout.info('INFO: Saving snapshot "{}"'.format(snapshot_name))
+            ws.saveSnapshot(snapshot_name, mutable_vars)
     
         if restore_states == 0:
             # load back a snapshot of all variable's initial states
