@@ -1,7 +1,8 @@
-from quickstats.components.workspaces.xml_ws_base import XMLWSBase, WSObjectType, XMLAttribType
+from quickstats.components.workspaces.xml_ws_base import XMLWSBase, WSObjectType, XMLAttribType, BracketType
 from quickstats.components.workspaces.sample import Sample
 from quickstats.components.workspaces.systematic import Systematic
 from quickstats.components.workspaces.asimov_handler import AsimovHandler
 from quickstats.components.workspaces.xml_ws_builder import XMLWSBuilder
 from quickstats.components.workspaces.xml_ws_modifier import XMLWSModifier
+from quickstats.components.workspaces.xml_ws_combiner import XMLWSCombiner
 from quickstats.components.workspaces.ws_comparer import WSComparer
\ No newline at end of file
