@@ -110,15 +110,24 @@ class XMLWSBase(AbstractObject):
         return xml_dict
     
     @staticmethod
-    def _get_node_attrib(node:Dict, attrib_name:str, required:bool=True,
+    def _get_node_attrib(node:Dict, attrib_name:Union[str, List[str]], required:bool=True,
                          default:Optional[str]=None,
                          dtype:Union[XMLAttribType,str]='str'):
         attrib_node = node['attrib']
-        if attrib_name in attrib_node:
-            attrib_val = attrib_node[attrib_name]
-        else:
+        if isinstance(attrib_name, str):
+            attrib_name = [attrib_name]
+        # aliases
+        found_attribute = False
+        for name in attrib_name:
+            if name in attrib_node:
+                if found_attribute:
+                    raise RuntimeError("values defined for multiple alises of the same attribute: "
+                                      f"{','.join(attrib_name)}")
+                attrib_val = attrib_node[name]
+                found_attribute = True
+        if not found_attribute:
             if required:
-                raise RuntimeError(f"attribute `{attrib_name}` not found in the "
+                raise RuntimeError(f"attribute `{','.join(attrib_name)}` not found in the "
                                    f"node `{node['tag']}`")
             else:
                 attrib_val = default
