@@ -749,15 +749,15 @@ class XMLWSBuilder(XMLWSBase):
     @staticmethod
     def _find_bin(h:ROOT.TH1, low_edge:float):
         h_first_bin = h.GetBinLowEdge(1)
-        if (low_edge < h_first_bin) and abs(low_edge - h_first_bin > self.EPSILON):
+        if (low_edge < h_first_bin) and abs(low_edge - h_first_bin > XMLWSBuilder.EPSILON):
             return 0
         n_bins = h.GetNbinsX()
         h_last_bin = h.GetBinLowEdge(n_bins)
-        if (low_edge > h_last_bin) and abs(low_edge - h_last_bin > self.EPSILON):
+        if (low_edge > h_last_bin) and abs(low_edge - h_last_bin > XMLWSBuilder.EPSILON):
             return n_bins + 1
         for i in range(1, n_bins + 1):
             bin_edge = h.GetBinLowEdge(i)
-            if abs(bin_edge - low_edge) < self.EPSILON:
+            if abs(bin_edge - low_edge) < XMLWSBuilder.EPSILON:
                 return i
         return -1
         
@@ -1033,9 +1033,11 @@ class XMLWSBuilder(XMLWSBase):
     
     def get_histogram(self, filename:str, histname:str, check_only:bool=False):
         filepath = self.get_relpath(filename)
-        if os.path.exists(filepath):
+        if not os.path.exists(filepath):
             raise FileNotFoundError(f"input data file `{filepath}` not found")
         f = ROOT.TFile(filepath)
+        category_name = self.current_category
+        data_config = self.cat_config[category_name]['dataset']
         histname = data_config['histname']
         histogram = f.Get(histname)
         if not isinstance(histogram, ROOT.TH1):
@@ -1060,7 +1062,7 @@ class XMLWSBuilder(XMLWSBase):
             if data_config['filetype'] != self.KEYWORDS['ascii']:
                 if data_config['filetype'] == self.KEYWORDS['histogram']:
                     histname = data_config['histname']
-                    self.get_histogram(fileame, histname, check_only=True)
+                    self.get_histogram(filename, histname, check_only=True)
                 else:
                     treename = data_config['treename']
                     varname = data_config['varname']
@@ -1250,7 +1252,7 @@ class XMLWSBuilder(XMLWSBase):
         if data_filetype != self.KEYWORDS['ascii']:
             # reading from ntuples/histogram
             if data_filetype == self.KEYWORDS['histogram']:
-                data_config['histname'] = self._translate_node_attrib(node, "HistName")
+                data_config['histname'] = self._translate_node_attrib(node, ["HistName", "HistoName"])
             else:
                 data_config['treename'] = self._translate_node_attrib(node, "TreeName")
                 data_config['varname'] = self._translate_node_attrib(node, "VarName")
@@ -1653,7 +1655,7 @@ class XMLWSBuilder(XMLWSBase):
         h = self.get_histogram(filename, histname)
         if rebin > 0:
             h.Rebin(rebin)
-        obs = w.var(obs_name)
+        obs = ws.var(obs_name)
         if not obs:
             raise RuntimeError("observable not initialized")
         h_data = ROOT.RooDataHist("hdata", "hdata", obs, h)
@@ -1699,4 +1701,4 @@ class XMLWSBuilder(XMLWSBase):
                 self.stdout.debug("REGTEST: All nuisance parameters: ")
                 nuis.Print()
         else:
-            self.stdout.info("REGTEST: Number of nuisance parameters looks good!")
\ No newline at end of file
+            self.stdout.info("REGTEST: Number of nuisance parameters looks good!")
