@@ -318,7 +318,7 @@ class XMLWSCombiner(XMLWSBase):
             if not glob:
                 msg = missing_obj_msg.format(obj_type="Global observable", obj_name=glob_name)
                 raise RuntimeError(msg)
-            nuis_check, glob_check, sigma_check = False, False, False
+            nuis_check, glob_check, sigma_check, glob_value = False, False, False, None
             # this part can be optimized after ROOT 6.26
             server_iter = pdf.serverIterator()
             while True:
@@ -330,9 +330,10 @@ class XMLWSCombiner(XMLWSBase):
                     nuis_check = True
                 elif server_name == glob_name:
                     glob_check = True
+                    glob_value = server.getVal()
                 elif abs(server.getVal() - 1) < self.EPSILON:
                     sigma_check = True
-            if not sigma_check:
+            if (not sigma_check) and (glob_value != 1.):
                 raise RuntimeError(f"sigma of constraint pdf \"{pdf_name}\" in the workspace \"{ws_filename}\" is not unity")
         for var_name in renamed_vars:
             if not model.workspace.var(var_name):
