@@ -238,11 +238,13 @@ class XMLWSModifier(XMLWSBase):
         nuis_name = self._get_node_attrib(node, "NP", required=False, default=[], dtype="str_list")
         glob_name = self._get_node_attrib(node, "GO", required=False, default=[], dtype="str_list")
         filename  = self._get_node_attrib(node, "FileName", required=False)
+        independent  = self._get_node_attrib(node, "Independent", required=False, default="false", dtype="bool")
         result = {
             'pdf': pdf_name,
             'nuis': nuis_name,
             'glob': glob_name,
-            'file': filename
+            'file': filename,
+            'independent': independent
         }
         return result
     
@@ -559,7 +561,7 @@ class XMLWSModifier(XMLWSBase):
                 self.stdout.warning(f"WARNING: The global observable {glob_name} is initialized as a floating "
                                     "parameter. It will be set to constant in the new workspace.")
 
-                new_nuis.setConstant(True)
+                glob.setConstant(True)
             global_observables.add(glob)
 
         # set observables
@@ -791,21 +793,29 @@ class XMLWSModifier(XMLWSBase):
                 constraints = pdf_i.getAllConstraints(observables, nuisance_parameters, True)
                 base_components.add(constraints)
             
+            new_pdf_name = f"{pdf_i.GetName()}__addConstr"
             # adding additional constraint pdf
             for i, item in enumerate(self.actions['constraint']):
                 pdf_name = item['pdf']
                 nuis_names = item['nuis']
                 glob_names = item['glob']
+                independent = item['independent']
                 new_pdf = new_ws.pdf(pdf_name)
                 if not new_pdf:
                     raise RuntimeError(f"pdf {pdf_name} does not exist in the new workspace")
+                if independent:
+                    base_components.add(new_pdf)
+                    self.stdout.info(f"INFO: Adding independent constraint pdf \"{pdf_name}\" to "
+                                     f"\"{new_pdf_name}\"")
+                    continue
                 # check whether the current category depends on the constraint pdf
                 for nuis_name in nuis_names:
                     nuis_var = self._get_relevant_variable(nuis_name, new_ws, pdf_i)
-                    if nuis_var is not None:
+                    if (nuis_var is not None):
                         base_components.add(new_pdf)
                         break
-            new_pdf_name = f"{pdf_i.GetName()}__addConstr"
+                        
+            
             pdf_map[category_name] = ROOT.RooProdPdf(new_pdf_name, new_pdf_name, base_components)
         c_pdf_map = ExtendedModel.get_pdf_map(pdf_map)
         pdf_name = old_mc.GetPdf().GetName()
