@@ -21,13 +21,14 @@ class ParameterisedRunner(AbstractRunner):
                  exclude_expr:Optional[str]=None,
                  parallel:int=-1, timed:bool=True,
                  save_log:bool=True, cache:bool=True,
+                 allow_none:bool=True,
                  verbosity:Optional[Union[int, str]]="INFO"):
         
         super().__init__(parallel=parallel, timed=timed, save_log=save_log,
                          cache=cache, verbosity=verbosity)
         self.filter_expr = filter_expr
         self.exclude_expr = exclude_expr
-        self._parser = ParamParser(file_expr, param_expr)
+        self._parser = ParamParser(file_expr, param_expr, allow_none=allow_none)
         self._param_points = None
         self.param_ind_kwargs = {}
         self.param_dpd_kwargs = {}
