@@ -3,7 +3,7 @@ import quickstats
 from .color_schemes import *
 from .abstract_plot import AbstractPlot
 from .hypotest_inverter_plot import HypoTestInverterPlot
-from .score_distribution_plot import score_distribution_plot, score_distribution_plot_2D
+from .score_distribution_plot import score_distribution_plot, score_distribution_plot_2D, ScoreDistributionPlot
 from .test_statistic_distribution_plot import TestStatisticDistributionPlot
 from .general_1D_plot import General1DPlot
 from .upper_limit_1D_plot import UpperLimit1DPlot
