@@ -221,18 +221,29 @@ class PdfDistributionPlot(AbstractPlot):
             combined_options['capthick'] = 0
         draw_blind = blind_range is not None
         if draw_blind:
+            x = pdata_comp['x'][pdata_ref['sideband']]
+            y = pdata_comp['y'][pdata_ref['sideband']]
             xerr = self._get_selected_err(pdata_comp['xerr'], pdata_ref['sideband'])
             yerr = self._get_selected_err(pdata_comp['yerr'], pdata_ref['sideband'])
-            handle = ax.errorbar(pdata_comp['x'][pdata_ref['sideband']],
-                                 pdata_comp['y'][pdata_ref['sideband']],
+            handle = ax.errorbar(x, y,
                                  xerr=xerr,
                                  yerr=yerr,
                                  **combined_options)
         else:
-            handle = ax.errorbar(pdata_comp['x'], pdata_comp['y'],
+            x = pdata_comp['x']
+            y = pdata_comp['y']
+            handle = ax.errorbar(x, y,
                                  xerr=pdata_comp['xerr'],
                                  yerr=pdata_comp['yerr'],
                                   **combined_options)
+            
+        ylim = list(ax.get_ylim())
+        if ylim[0] > np.min(y):
+            ylim[0] = np.min(y)
+        if ylim[1] < np.max(y):
+            ylim[1] = np.max(y)
+        ax.set_ylim(ylim)
+        
         if vmode == 0:
             centralize_axis(ax, which="y", ref_value=1)
             if draw_ratio_line:
@@ -337,4 +348,7 @@ class PdfDistributionPlot(AbstractPlot):
             kwargs = combine_dict(self.styles['annotation'], self.annotation)
             ax.annotate(**kwargs)
             
+        if comparison_options:
+            return ax, ax_ratio
+        
         return ax
\ No newline at end of file
