@@ -166,7 +166,7 @@ def ratio_frames(height_ratios:Tuple[int]=(3, 1), hspace:float=0.07,
                       ytick_styles=styles['ytick'], **styles['axis'])
     
     if analysis_label_options is not None:
-        draw_analysis_label(ax1, dy=0.05, text_options=styles['text'], **analysis_label_options)
+        draw_analysis_label(ax1, text_options=styles['text'], **analysis_label_options)
         
     if prop_cycle is not None:
         ax1.set_prop_cycle(prop_cycle)
@@ -297,7 +297,7 @@ def centralize_axis(ax, which='x', ref_value:float=0, padding:float=0.1):
         set_lim = ax.set_ylim    
     limits = get_lim()
     vmax = np.max(np.abs([ref_value - limits[0], limits[1] - ref_value]))
-    pad = vmax * padding
+    pad = (limits[1] - limits[0]) * padding
     set_lim(ref_value - vmax - pad, ref_value + vmax + pad)
         
 def parse_transform(obj:str):
@@ -350,10 +350,13 @@ def draw_hatches(axis, ymax, height=1.0, **styles):
 
 def draw_text(axis, x, y, s, transform_x:str='axis', 
               transform_y:str='axis', **styles):
+    current_axis = plt.gca()
+    plt.sca(axis)
     transform = transforms.blended_transform_factory(parse_transform(transform_x), 
                                                      parse_transform(transform_y))
     text = axis.text(x, y, s, transform=transform, **styles)
     xmin, xmax, ymin, ymax = get_box_dimension(text)
+    plt.sca(current_axis)
     return xmin, xmax, ymin, ymax
 
 
@@ -378,8 +381,8 @@ def _draw_analysis_label(axis, loc=(0.05, 0.95), fontsize=25, extra='Internal',
     dx = text_width/15
     text_extra = axis.text(xmax + dx, ymin, extra, fontsize=fontsize, transform=axis.transAxes,
                            horizontalalignment='left', verticalalignment='bottom')
-    plt.sca(current_axis)
     _, xmax, _, ymax = get_box_dimension(text_atlas)
+    plt.sca(current_axis)
     return xmin, xmax, ymin, ymax
 
 def draw_analysis_label(axis, loc=(0.05, 0.95), fontsize=25, status:str='int',
