@@ -155,7 +155,8 @@ class UpperLimit2DPlot(AbstractPlot):
                          sigma_band_hatch:Optional[str]=None,
                          alpha:float=1.,
                          linewidth:float=1.,
-                         sec:bool=False):
+                         sec:bool=False,
+                         draw_errorband:bool=True):
         
         if color_pallete is None:
             color_pallete = self.color_pallete
@@ -174,18 +175,19 @@ class UpperLimit2DPlot(AbstractPlot):
         handles_map = {}
         
         # draw +- 1, 2 sigma bands 
-        handle_2sigma = ax.fill_between(indices, n2sigma_limits, p2sigma_limits, 
-                                        facecolor=color_pallete['2sigma'],
-                                        label=labels['2sigma'],
-                                        hatch=sigma_band_hatch,
-                                        alpha=alpha)
-        handle_1sigma = ax.fill_between(indices, n1sigma_limits, p1sigma_limits, 
-                                        facecolor=color_pallete['1sigma'],
-                                        label=labels['1sigma'],
-                                        hatch=sigma_band_hatch,
-                                        alpha=alpha)
-        handles_map['1sigma'] = handle_1sigma
-        handles_map['2sigma'] = handle_2sigma
+        if draw_errorband:
+            handle_2sigma = ax.fill_between(indices, n2sigma_limits, p2sigma_limits, 
+                                            facecolor=color_pallete['2sigma'],
+                                            label=labels['2sigma'],
+                                            hatch=sigma_band_hatch,
+                                            alpha=alpha)
+            handle_1sigma = ax.fill_between(indices, n1sigma_limits, p1sigma_limits, 
+                                            facecolor=color_pallete['1sigma'],
+                                            label=labels['1sigma'],
+                                            hatch=sigma_band_hatch,
+                                            alpha=alpha)
+            handles_map['1sigma'] = handle_1sigma
+            handles_map['2sigma'] = handle_2sigma
         
         if log:
             draw_fn = ax.semilogy
@@ -209,7 +211,9 @@ class UpperLimit2DPlot(AbstractPlot):
         self.update_legend_handles(handles_map, sec=sec)
             
     def draw(self, xlabel:str="", ylabel:str="", ylim=None, xlim=None,
-             log:bool=False, draw_observed:bool=True, observed_marker:Optional[str]='o', linewidth:float=1):
+             log:bool=False, draw_observed:bool=True, draw_errorband:bool=True,
+             observed_marker:Optional[str]='o',
+             linewidth:float=1):
         
         ax = self.draw_frame()
         
@@ -223,7 +227,8 @@ class UpperLimit2DPlot(AbstractPlot):
                                   observed_marker=observed_marker, 
                                   sigma_band_hatch=self.config['secondary_hatch'],
                                   alpha=self.config['secondary_alpha'],
-                                  sec=True)
+                                  sec=True,
+                                  draw_errorband=draw_errorband)
             sigma_band_hatch = self.config['primary_hatch']
             alpha = self.config['primary_alpha']
         else:
@@ -238,7 +243,8 @@ class UpperLimit2DPlot(AbstractPlot):
                               observed_marker=observed_marker, 
                               sigma_band_hatch=sigma_band_hatch,
                               alpha=alpha,
-                              linewidth=linewidth)
+                              linewidth=linewidth,
+                              draw_errorband=draw_errorband)
         if self.curve_data is not None:
             self.draw_curve(ax, self.curve_data)   
         if self.highlight_data is not None:
@@ -253,14 +259,16 @@ class UpperLimit2DPlot(AbstractPlot):
 
         # border for the legend
         border_leg = patches.Rectangle((0, 0), 1, 1, facecolor = 'none', edgecolor = 'black', linewidth = 1)
-        self.legend_data['1sigma']['handle'] = (self.legend_data['1sigma']['handle'], border_leg)
-        self.legend_data['2sigma']['handle'] = (self.legend_data['2sigma']['handle'], border_leg)
+        
+        if draw_errorband:
+            self.legend_data['1sigma']['handle'] = (self.legend_data['1sigma']['handle'], border_leg)
+            self.legend_data['2sigma']['handle'] = (self.legend_data['2sigma']['handle'], border_leg)
         
         if self.curve_data is not None:
             if isinstance(self.legend_data['curve']['handle'], tuple):
                 self.legend_data['curve']['handle'] = (*self.legend_data['curve']['handle'], border_leg)
         
-        if self.data_sec is not None:
+        if (self.data_sec is not None) and (draw_errorband):
             self.legend_data_sec['1sigma']['handle'] = (self.legend_data_sec['1sigma']['handle'], border_leg)
             self.legend_data_sec['2sigma']['handle'] = (self.legend_data_sec['2sigma']['handle'], border_leg)
             
